/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser;

import org.json.JSONObject;

/**
 * @author Michael Hashimoto
 */
public class Label {

	public Label(JSONObject jsonObject, GitHubRemoteRepository repository) {
		_jsonObject = jsonObject;
		_repository = repository;
	}

	@Override
	public boolean equals(Object o) {
		if (o == null) {
			return false;
		}

		if (!(o instanceof Label)) {
			return false;
		}

		Label label = (Label)o;

		String color = getColor();
		String name = getName();

		if (color.equals(label.getColor()) && name.equals(label.getName())) {
			return true;
		}

		return false;
	}

	public String getColor() {
		return _jsonObject.getString("color");
	}

	public String getDescription() {
		return _jsonObject.optString("description");
	}

	public String getName() {
		return _jsonObject.getString("name");
	}

	public GitHubRemoteRepository getRepository() {
		return _repository;
	}

	@Override
	public int hashCode() {
		String name = getName();

		return name.hashCode();
	}

	@Override
	public String toString() {
		return _jsonObject.toString(4);
	}

	private final JSONObject _jsonObject;
	private final GitHubRemoteRepository _repository;

}