/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.jenkins.results.parser.failure.message.generator;

import com.liferay.jenkins.results.parser.Build;
import com.liferay.jenkins.results.parser.Dom4JUtil;

import org.dom4j.Element;

/**
 * @author Peter Yoo
 */
public class LocalGitMirrorFailureMessageGenerator
	extends BaseFailureMessageGenerator {

	@Override
	public Element getMessageElement(Build build) {
		String consoleText = build.getConsoleText();

		if (!consoleText.contains(_TOKEN_LOCAL_GIT_FAILURE_END) ||
			!consoleText.contains(_TOKEN_LOCAL_GIT_FAILURE_START)) {

			return null;
		}

		Element messageElement = Dom4JUtil.getNewElement("div");

		Dom4JUtil.getNewElement(
			"p", messageElement, "Unable to synchronize with ",
			Dom4JUtil.getNewElement("strong", null, "local Git mirror"), ".");

		int end = consoleText.indexOf(_TOKEN_LOCAL_GIT_FAILURE_END);

		int start = consoleText.lastIndexOf(
			_TOKEN_LOCAL_GIT_FAILURE_START, end);

		consoleText = consoleText.substring(start, end);

		int minIndex = consoleText.length();

		for (String string : new String[] {"error: ", "fatal: "}) {
			int index = consoleText.indexOf(string);

			if (index != -1) {
				if (index < minIndex) {
					minIndex = index;
				}
			}
		}

		int gitCommandIndex = consoleText.lastIndexOf("+ git", minIndex);

		if (gitCommandIndex != -1) {
			start = gitCommandIndex;
		}

		start = consoleText.lastIndexOf("\n", start);

		end = consoleText.lastIndexOf("\n");

		messageElement.add(
			getConsoleTextSnippetElement(consoleText, false, start, end));

		return messageElement;
	}

	private static final String _TOKEN_LOCAL_GIT_FAILURE_END = "BUILD FAILED";

	private static final String _TOKEN_LOCAL_GIT_FAILURE_START =
		"Too many retries while synchronizing GitHub pull request.";

}